# Generated by Django 2.2.3 on 2019-09-05 13:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("response", "0005_auto_20190906_1413")]

    operations = [
        migrations.AddField(
            model_name="externaluser",
            name="full_name",
            field=models.CharField(blank=True, max_length=50, null=True),
        )
    ]
